SvgIcon class

Annotations
  • @freezed

Constructors

SvgIcon({required int id, required String name, required String path, @Default.new(false) bool selected})
const
factory
SvgIcon.fromJson(Json json)
factory

Properties

charCode → String
no setter
copyWith → $SvgIconCopyWith<SvgIcon>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hexCode → String
no setter
id → int
no setterinherited
name → String
no setterinherited
path → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited